@@ -14,7 +14,7 @@ class Client():
     config = None
     http = None
 
-    def __init__(self, url, apiKey=None):
+    def __init__(self, url, apiKey=None, timeout=None):
         """
         Parameters
         ----------
@@ -23,7 +23,8 @@ class Client():
         apiKey : str
             The optional API key for MeiliSearch
         """
-        self.config = Config(url, apiKey)
+        self.config = Config(url, apiKey, timeout=timeout)
+
         self.http = HttpRequests(self.config)
 
     def create_index(self, uid, options=None):
@@ -134,7 +135,7 @@ class Client():
         """Get all stats of MeiliSearch
 
         Get information about database size and all indexes
-        https://docs.meilisearch.com/references/stats.html
+        https://docs.meilisearch.com/reference/api/stats.html
 
         Returns
         -------
@@ -163,13 +164,13 @@ class Client():
     def get_keys(self):
         """Get all keys.
 
-        Get list of all the keys.
+        Get the public and private keys.
 
         Returns
         -------
-        keys: list
-            List of keys and their information.
-            https://docs.meilisearch.com/references/keys.html#get-keys
+        keys: dict
+            Dictionary of keys and their information.
+            https://docs.meilisearch.com/reference/api/keys.html#get-keys
 
         Raises
         ------
@@ -215,7 +216,7 @@ class Client():
         -------
         Dump: dict
             Information about the dump.
-            https://docs.meilisearch.com/references/dump.html#create-a-dump
+            https://docs.meilisearch.com/reference/api/dump.html#create-a-dump
 
         Raises
         ------
@@ -236,7 +237,7 @@ class Client():
         -------
         Dump status: dict
             Information about the dump status.
-            https://docs.meilisearch.com/references/dump.html#get-dump-status
+            https://docs.meilisearch.com/reference/api/dump.html#get-dump-status
 
         Raises
         ------
